@@ -13,6 +13,7 @@ from mako.template import Template
 from bcbio.broad import runner_from_config
 from bcbio.broad.metrics import PicardMetrics, PicardMetricsParser
 from bcbio import utils
+from bcbio.pipeline import config_utils
 
 # ## High level functions to generate summary PDF
 
@@ -55,7 +56,7 @@ def _generate_pdf(graphs, summary, overrep, bam_file, sample_name,
     with open(out_file, "w") as out_handle:
         out_handle.write(out_tmpl.render(parts=[section]))
     if config["algorithm"].get("write_summary", True):
-        cl = [config.get("program", {}).get("pdflatex", "pdflatex"), out_file]
+        cl = [config_utils.get_program("pdflatex", config), out_file]
         subprocess.check_call(cl)
     return "%s.pdf" % os.path.splitext(out_file)[0]
 
@@ -212,7 +213,7 @@ def _run_fastqc(bam_file, config):
     fastqc_out = os.path.join(out_base, "%s_fastqc" %
                               os.path.splitext(os.path.basename(bam_file))[0])
     if not os.path.exists(fastqc_out):
-        cl = [config.get("program", {}).get("fastqc", "fastqc"),
+        cl = [config_utils.get_program("fastqc", config),
               "-o", out_base, "-f", "bam", bam_file]
         subprocess.check_call(cl)
     if os.path.exists("%s.zip" % fastqc_out):
@@ -231,16 +232,17 @@ def write_metrics(run_info, fc_name, fc_date, dirs):
     with open(out_file, "w") as out_handle:
         metrics = dict(lanes=lane_stats, samples=sample_stats)
         yaml.dump(metrics, out_handle, default_flow_style=False)
-    tab_out_file = os.path.join(dirs["flowcell"], "run_summary.tsv")
-    try:
-        with open(tab_out_file, "w") as out_handle:
-            writer = csv.writer(out_handle, dialect="excel-tab")
-            for info in tab_metrics:
-                writer.writerow(info)
-    # If on NFS mounted directory can fail due to filesystem or permissions
-    # errors. That's okay, we'll just not write the file.
-    except IOError:
-        pass
+    if dirs["flowcell"]:
+        tab_out_file = os.path.join(dirs["flowcell"], "run_summary.tsv")
+        try:
+            with open(tab_out_file, "w") as out_handle:
+                writer = csv.writer(out_handle, dialect="excel-tab")
+                for info in tab_metrics:
+                    writer.writerow(info)
+        # If on NFS mounted directory can fail due to filesystem or permissions
+        # errors. That's okay, we'll just not write the file.
+        except IOError:
+            pass
     return out_file
 
 def summary_metrics(run_info, analysis_dir, fc_name, fc_date, fastq_dir):
@@ -293,16 +295,17 @@ def _metrics_from_stats(stats):
 def _bustard_stats(lane_num, fastq_dir, fc_date, analysis_dir):
     """Extract statistics about the flow cell from Bustard outputs.
     """
-    sum_file = os.path.join(fastq_dir, os.pardir, "BustardSummary.xml")
-    #sum_file = os.path.join(fc_dir, "Data", "Intensities", "BaseCalls",
-    #        "BustardSummary.xml")
     stats = dict()
-    if os.path.exists(sum_file):
-        with open(sum_file) as in_handle:
-            results = ET.parse(in_handle).getroot().find("TileResultsByLane")
-            for lane in results:
-                if lane.find("laneNumber").text == str(lane_num):
-                    stats = _collect_cluster_stats(lane)
+    if fastq_dir:
+        sum_file = os.path.join(fastq_dir, os.pardir, "BustardSummary.xml")
+        #sum_file = os.path.join(fc_dir, "Data", "Intensities", "BaseCalls",
+        #        "BustardSummary.xml")
+        if os.path.exists(sum_file):
+            with open(sum_file) as in_handle:
+                results = ET.parse(in_handle).getroot().find("TileResultsByLane")
+                for lane in results:
+                    if lane.find("laneNumber").text == str(lane_num):
+                        stats = _collect_cluster_stats(lane)
     read_stats = _calc_fastq_stats(analysis_dir, lane_num, fc_date)
     stats.update(read_stats)
     return stats
@@ -348,7 +351,7 @@ _section_template = r"""
     \hline
     % for label, val, extra in summary_table:
         %if label is not None:
-            ${label} & ${val} & ${extra} \\ 
+            ${label} & ${val} & ${extra} \\%
         %else:
             \hline
         %endif
@@ -378,10 +381,10 @@ _section_template = r"""
     \centering
     \begin{tabular}{|p{8cm}rrp{4cm}|}
     \hline
-    Sequence & Count & Percent & Match \\ 
+    Sequence & Count & Percent & Match \\%
     \hline
     % for seq, count, percent, match in overrep:
-        \texttt{${seq}} & ${count} & ${"%.2f" % float(percent)} & ${match} \\ 
+        \texttt{${seq}} & ${count} & ${"%.2f" % float(percent)} & ${match} \\%
     % endfor
     \hline
     \end{tabular}
