@@ -2,6 +2,7 @@
 """
 import os
 import tempfile
+import time
 import shutil
 import contextlib
 import itertools
@@ -12,7 +13,7 @@ try:
     from multiprocessing.pool import IMapIterator
 except ImportError:
     multiprocessing = None
-
+import collections
 import yaml
 
 @contextlib.contextmanager
@@ -76,21 +77,30 @@ def memoize_outfile(ext):
 def safe_makedir(dname):
     """Make a directory if it doesn't exist, handling concurrent race conditions.
     """
-    if not os.path.exists(dname):
+    num_tries = 0
+    max_tries = 5
+    while not os.path.exists(dname):
         # we could get an error here if multiple processes are creating
         # the directory at the same time. Grr, concurrency.
         try:
             os.makedirs(dname)
         except OSError:
-            if not os.path.isdir(dname):
+            if num_tries > max_tries:
                 raise
+            num_tries += 1
+            time.sleep(2)
     return dname
 
 @contextlib.contextmanager
-def curdir_tmpdir(remove=True):
+def curdir_tmpdir(remove=True, base_dir=None):
     """Context manager to create and remove a temporary directory.
+
+    This can also handle a configured temporary directory to use.
     """
-    tmp_dir_base = os.path.join(os.getcwd(), "tmp")
+    if base_dir is not None:
+        tmp_dir_base = os.path.join(base_dir, "bcbiotmp")
+    else:
+        tmp_dir_base = os.path.join(os.getcwd(), "tmp")
     safe_makedir(tmp_dir_base)
     tmp_dir = tempfile.mkdtemp(dir=tmp_dir_base)
     safe_makedir(tmp_dir)
@@ -98,7 +108,10 @@ def curdir_tmpdir(remove=True):
         yield tmp_dir
     finally :
         if remove:
-            shutil.rmtree(tmp_dir)
+            try:
+                shutil.rmtree(tmp_dir)
+            except:
+                pass
 
 @contextlib.contextmanager
 def chdir(new_dir):
@@ -166,6 +179,41 @@ def add_full_path(dirname, basedir=None):
         dirname = os.path.join(basedir, dirname)
     return dirname
 
+
+def append_stem(filename, word, delim="_"):
+    """
+    returns a filename with 'word' appended to the stem
+    example: append_stem("/path/to/test.sam", "filtered") ->
+    "/path/to/test_filtered.sam"
+
+    """
+    (base, ext) = os.path.splitext(filename)
+    return "".join([base, delim, word, ext])
+
+
+def replace_suffix(filename, suffix):
+    """
+    replace the suffix of filename with suffix
+    example: replace_suffix("/path/to/test.sam", ".bam") ->
+    "/path/to/test.bam"
+
+    """
+    (base, _) = os.path.splitext(filename)
+    return base + suffix
+
+# ## Functional programming
+
+def partition_all(n, iterable):
+    """Partition a list into equally sized pieces, including last smaller parts
+    http://stackoverflow.com/questions/5129102/python-equivalent-to-clojures-partition-all
+    """
+    it = iter(iterable)
+    while True:
+        chunk = list(itertools.islice(it, n))
+        if not chunk:
+            break
+        yield chunk
+
 # ## Dealing with configuration files
 
 def merge_config_files(fnames):
@@ -184,3 +232,55 @@ def merge_config_files(fnames):
             else:
                 out[k] = v
     return out
+
+
+def get_in(d, t, default=None):
+    """
+    look up if you can get a tuple of values from a nested dictionary,
+    each item in the tuple a deeper layer
+
+    example: get_in({1: {2: 3}}, (1, 2)) -> 3
+    example: get_in({1: {2: 3}}, (2, 3)) -> {}
+    """
+    result = reduce(lambda d, t: d.get(t, {}), t, d)
+    if not result:
+        return default
+    else:
+        return result
+
+
+def flatten(l):
+    """
+    flatten an irregular list of lists
+    example: flatten([[[1, 2, 3], [4, 5]], 6]) -> [1, 2, 3, 4, 5, 6]
+    lifted from: http://stackoverflow.com/questions/2158395/
+
+    """
+    for el in l:
+        if isinstance(el, collections.Iterable) and not isinstance(el,
+                                                                   basestring):
+            for sub in flatten(el):
+                yield sub
+        else:
+            yield el
+
+
+def is_sequence(arg):
+    """
+    check if 'arg' is a sequence
+
+    example: arg([]) -> True
+    example: arg("lol") -> False
+
+    """
+    return (not hasattr(arg, "strip") and
+            hasattr(arg, "__getitem__") or
+            hasattr(arg, "__iter__"))
+
+
+def is_pair(arg):
+    """
+    check if 'arg' is a two-item sequence
+
+    """
+    return is_sequence(arg) and len(arg) == 2
