@@ -15,30 +15,33 @@ import itertools
 import collections
 
 from bcbio import broad
+from bcbio.log import logger
 from bcbio.utils import file_exists
 from bcbio.distributed.transaction import file_transaction
-from bcbio.distributed.split import parallel_split_combine
+from bcbio.distributed.split import (parallel_split_combine,
+                                     grouped_parallel_split_combine)
 from bcbio.pipeline.shared import (process_bam_by_chromosome, configured_ref_file,
                                    subset_variant_regions)
 from bcbio.variation.realign import has_aligned_reads
+from bcbio.variation import multi
 
 # ## GATK Genotype calling
 
-def _shared_gatk_call_prep(align_bam, ref_file, config, dbsnp, region, out_file):
+def _shared_gatk_call_prep(align_bams, ref_file, config, dbsnp, region, out_file):
     """Shared preparation work for GATK variant calling.
     """
     broad_runner = broad.runner_from_config(config)
     broad_runner.run_fn("picard_index_ref", ref_file)
-    broad_runner.run_fn("picard_index", align_bam)
+    for x in align_bams:
+        broad_runner.run_fn("picard_index", x)
     coverage_depth = config["algorithm"].get("coverage_depth", "high").lower()
     variant_regions = config["algorithm"].get("variant_regions", None)
     confidence = "4.0" if coverage_depth in ["low"] else "30.0"
     if out_file is None:
-        out_file = "%s-variants.vcf" % os.path.splitext(align_bam)[0]
+        out_file = "%s-variants.vcf" % os.path.splitext(align_bams[0])[0]
     region = subset_variant_regions(variant_regions, region, out_file)
 
-    params = ["-I", align_bam,
-              "-R", ref_file,
+    params = ["-R", ref_file,
               "--annotation", "QualByDepth",
               "--annotation", "HaplotypeScore",
               "--annotation", "MappingQualityRankSumTest",
@@ -49,21 +52,23 @@ def _shared_gatk_call_prep(align_bam, ref_file, config, dbsnp, region, out_file)
               "--standard_min_confidence_threshold_for_calling", confidence,
               "--standard_min_confidence_threshold_for_emitting", confidence,
               ]
+    for x in align_bams:
+        params += ["-I", x]
     if dbsnp:
         params += ["--dbsnp", dbsnp]
     if region:
         params += ["-L", region, "--interval_set_rule", "INTERSECTION"]
     return broad_runner, params, out_file
 
-def unified_genotyper(align_bam, ref_file, config, dbsnp=None,
+def unified_genotyper(align_bams, ref_file, config, dbsnp=None,
                        region=None, out_file=None):
     """Perform SNP genotyping on the given alignment file.
     """
     broad_runner, params, out_file = \
-        _shared_gatk_call_prep(align_bam, ref_file, config, dbsnp,
+        _shared_gatk_call_prep(align_bams, ref_file, config, dbsnp,
                                region, out_file)
     if not file_exists(out_file):
-        if not has_aligned_reads(align_bam, region):
+        if not all(has_aligned_reads(x, region) for x in align_bams):
             write_empty_vcf(out_file)
         else:
             with file_transaction(out_file) as tx_out_file:
@@ -80,12 +85,12 @@ def haplotype_caller(align_bam, ref_file, config, dbsnp=None,
     This requires the full non open-source version of GATK.
     """
     broad_runner, params, out_file = \
-        _shared_gatk_call_prep(align_bam, ref_file, config, dbsnp,
+        _shared_gatk_call_prep(align_bams, ref_file, config, dbsnp,
                                region, out_file)
     assert broad_runner.has_gatk_full(), \
         "Require full version of GATK 2.0 for haplotype based calling"
     if not file_exists(out_file):
-        if not has_aligned_reads(align_bam, region):
+        if not all(has_aligned_reads(x, region) for x in align_bams):
             write_empty_vcf(out_file)
         else:
             with file_transaction(out_file) as tx_out_file:
@@ -148,7 +153,7 @@ def combine_variant_files(orig_files, out_file, ref_file, config,
 def variant_filtration(call_file, ref_file, vrn_files, config):
     """Filter variant calls using Variant Quality Score Recalibration.
 
-    Newer GATK with Haplotype calling has
+    Newer GATK with Haplotype calling has combined SNP/indel filtering.
     """
     broad_runner = broad.runner_from_config(config)
     caller = config["algorithm"].get("variantcaller")
@@ -156,6 +161,9 @@ def variant_filtration(call_file, ref_file, vrn_files, config):
     if caller in ["gatk-haplotype"] and cov_interval not in ["regional"]:
         return _variant_filtration_both(broad_runner, call_file, ref_file, vrn_files,
                                         config)
+    # no additional filtration for callers that filter as part of call process
+    elif caller in ["samtools", "varscan"]:
+        return call_file
     else:
         snp_file, indel_file = split_snps_indels(broad_runner, call_file, ref_file)
         snp_filter_file = _variant_filtration_snp(broad_runner, snp_file, ref_file,
@@ -233,6 +241,7 @@ def variant_filtration_with_exp(broad_runner, snp_file, ref_file, filter_type,
     out_file = "{base}-filter{ftype}{ext}".format(base=base, ext=ext,
                                                   ftype=filter_type)
     if not file_exists(out_file):
+        logger.info("Hard filtering %s with %s" % (snp_file, expressions))
         with file_transaction(out_file) as tx_out_file:
             params = ["-T", "VariantFiltration",
                       "-R", ref_file,
@@ -257,12 +266,15 @@ def _variant_filtration_snp(broad_runner, snp_file, ref_file, vrn_files,
         filter_type, cov_interval, snp_file, ref_file, vrn_files)
     assert vrn_files.train_hapmap and vrn_files.train_1000g_omni, \
            "Need HapMap and 1000 genomes training files"
+    filters = ["QD < 2.0", "MQ < 40.0", "FS > 60.0",
+               "MQRankSum < -12.5", "ReadPosRankSum < -8.0"]
+    # GATK Haplotype caller (v2.2) appears to have much larger HaplotypeScores
+    # resulting in excessive filtering, so avoid this metric
+    if variantcaller not in ["gatk-haplotype"]:
+        filters.append("HaplotypeScore > 13.0")
     if cov_interval == "regional" or variantcaller == "freebayes":
         return variant_filtration_with_exp(broad_runner, snp_file, ref_file, filter_type,
-                                           ["QD < 2.0", "MQ < 40.0", "FS > 60.0",
-                                            "HaplotypeScore > 13.0",
-                                            "MQRankSum < -12.5",
-                                            "ReadPosRankSum < -8.0"])
+                                           filters)
     else:
         # also check if we've failed recal and needed to do strict filtering
         filter_file = "{base}-filterSNP.vcf".format(base = os.path.splitext(snp_file)[0])
@@ -468,7 +480,12 @@ def combine_multiple_callers(data):
                         "vrn_file": x["vrn_file"]}
                        for x in grouped_calls]
         final = grouped_calls[0]
-        final["variants"] = ready_calls
+        def orig_variantcaller_order(x):
+            return final["config"]["algorithm"]["orig_variantcaller"].index(x["variantcaller"])
+        if len(ready_calls) > 1:
+            final["variants"] = sorted(ready_calls, key=orig_variantcaller_order)
+        else:
+            final["variants"] = ready_calls
         out.append([final])
     return out
 
@@ -483,6 +500,8 @@ def _handle_multiple_variantcallers(data):
         out = []
         for caller in callers:
             base = copy.deepcopy(data[0])
+            base["config"]["algorithm"]["orig_variantcaller"] = \
+              base["config"]["algorithm"]["variantcaller"]
             base["config"]["algorithm"]["variantcaller"] = caller
             out.append([base])
         return out
@@ -500,26 +519,32 @@ def parallel_variantcall(sample_info, parallel_fn):
     if len(to_process) > 0:
         split_fn = process_bam_by_chromosome("-variants.vcf", "work_bam",
                                              dir_ext_fn = _get_variantcaller)
-        processed = parallel_split_combine(to_process, split_fn, parallel_fn,
-                                           "variantcall_sample",
-                                           "combine_variant_files",
-                                           "vrn_file", ["sam_ref", "config"])
+        processed = grouped_parallel_split_combine(
+            to_process, split_fn, multi.group_batches, parallel_fn,
+            "variantcall_sample", "split_variants_by_sample", "combine_variant_files",
+            "vrn_file", ["sam_ref", "config"])
         finished.extend(processed)
     return finished
 
 def variantcall_sample(data, region=None, out_file=None):
     """Parallel entry point for doing genotyping of a region of a sample.
     """
-    from bcbio.variation import freebayes, cortex
+    from bcbio.variation import freebayes, cortex, samtools, varscan
     caller_fns = {"gatk": unified_genotyper,
                   "gatk-haplotype": haplotype_caller,
                   "freebayes": freebayes.run_freebayes,
-                  "cortex": cortex.run_cortex}
+                  "cortex": cortex.run_cortex,
+                  "samtools": samtools.run_samtools,
+                  "varscan": varscan.run_varscan}
     if data["config"]["algorithm"]["snpcall"]:
         sam_ref = data["sam_ref"]
         config = data["config"]
         caller_fn = caller_fns[config["algorithm"].get("variantcaller", "gatk")]
-        data["vrn_file"] = caller_fn(data["work_bam"], sam_ref, config,
+        if isinstance(data["work_bam"], basestring):
+            align_bams = [data["work_bam"]]
+        else:
+            align_bams = data["work_bam"]
+        data["vrn_file"] = caller_fn(align_bams, sam_ref, config,
                                      configured_ref_file("dbsnp", config, sam_ref),
                                      region, out_file)
     return [data]
