@@ -9,6 +9,8 @@ import shutil
 import contextlib
 import collections
 
+from nose.plugins.attrib import attr
+
 @contextlib.contextmanager
 def make_workdir():
     remove_old_dir = True
@@ -37,7 +39,7 @@ class AutomatedAnalysisTest(unittest.TestCase):
         download_data = [DlInfo("110106_FC70BUKAAXX.tar.gz", None, None),
                          DlInfo("genomes_automated_test.tar.gz", "genomes", 7),
                          DlInfo("110907_ERP000591.tar.gz", None, None),
-                         DlInfo("100326_FC6107FAAXX.tar.gz", None, 2)]
+                         DlInfo("100326_FC6107FAAXX.tar.gz", None, 3)]
         for dl in download_data:
             url = "http://chapmanb.s3.amazonaws.com/{fname}".format(fname=dl.fname)
             dirname = os.path.join(data_dir, os.pardir,
@@ -72,55 +74,60 @@ class AutomatedAnalysisTest(unittest.TestCase):
         else:
             return sample
 
+    @attr(speed=3)
     def test_3_full_pipeline(self):
         """Run full automated analysis pipeline with multiplexing.
         """
         self._install_test_files(self.data_dir)
         with make_workdir():
-            cl = ["automated_initial_analysis.py",
+            cl = ["bcbio_nextgen.py",
                   self._get_post_process_yaml(),
                   os.path.join(self.data_dir, os.pardir, "110106_FC70BUKAAXX"),
                   os.path.join(self.data_dir, "run_info.yaml")]
             subprocess.check_call(cl)
 
+    @attr(speed=3)
     def test_4_empty_fastq(self):
         """Handle analysis of empty fastq inputs from failed runs.
         """
         with make_workdir():
-            cl = ["automated_initial_analysis.py",
+            cl = ["bcbio_nextgen.py",
                   self._get_post_process_yaml(),
                   os.path.join(self.data_dir, os.pardir, "110221_empty_FC12345AAXX"),
                   os.path.join(self.data_dir, "run_info-empty.yaml")]
             subprocess.check_call(cl)
 
+    @attr(speed=2)
     def test_2_rnaseq(self):
         """Run an RNA-seq analysis with TopHat and Cufflinks.
         """
         self._install_test_files(self.data_dir)
         with make_workdir():
-            cl = ["automated_initial_analysis.py",
+            cl = ["bcbio_nextgen.py",
                   self._get_post_process_yaml(),
                   os.path.join(self.data_dir, os.pardir, "110907_ERP000591"),
                   os.path.join(self.data_dir, "run_info-rnaseq.yaml")]
             subprocess.check_call(cl)
 
+    @attr(speed=1)
     def test_1_variantcall(self):
         """Test variant calling with GATK pipeline.
         """
         self._install_test_files(self.data_dir)
         with make_workdir():
-            cl = ["automated_initial_analysis.py",
+            cl = ["bcbio_nextgen.py",
                   self._get_post_process_yaml(),
                   os.path.join(self.data_dir, os.pardir, "100326_FC6107FAAXX"),
                   os.path.join(self.data_dir, "run_info-variantcall.yaml")]
             subprocess.check_call(cl)
 
+    @attr(speed=2)
     def test_5_bam(self):
         """Allow BAM files as input to pipeline.
         """
         self._install_test_files(self.data_dir)
         with make_workdir():
-            cl = ["automated_initial_analysis.py",
+            cl = ["bcbio_nextgen.py",
                   self._get_post_process_yaml(),
                   os.path.join(self.data_dir, os.pardir, "100326_FC6107FAAXX"),
                   os.path.join(self.data_dir, "run_info-bam.yaml")]
